package com.galaxis.manatee.dao;


import com.galaxis.capsule.util.GalaxisRepository;
import com.galaxis.manatee.entity.chuanyun.data.object.ChuanyunSelfWorkHourDO;
import com.galaxis.manatee.entity.chuanyun.data.object.ChuanyunWorkHourDO;
import org.springframework.data.jpa.repository.Query;
import org.springframework.data.repository.query.Param;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;
import java.util.List;

/**
 * @author kxuan
 */
@Repository
public interface ChuanyunSelfWorkHourDao extends GalaxisRepository<ChuanyunSelfWorkHourDO,String> {

    /**
     * 根据项目id，用户id，日期获取工时数据
     * @param userId    用户Id
     * @param projectId 项目Id
     * @param dayLogDate    日志日期
     * @return  日工时记录
     */
    ChuanyunSelfWorkHourDO findByUserIdAndAndProjectIdAndAndDayLogDate(String userId, String projectId, LocalDateTime dayLogDate);

    /**
     * 根据用户Id，项目Id，起止时间获取工时列表
     * @param userId    用户Id
     * @param projectId 项目Id
     * @param status    状态
     * @param start     开始时间
     * @param end       结束时间
     * @return  日工时列表
     */
    List<ChuanyunSelfWorkHourDO> findAllByUserIdAndProjectIdAndStatusAndDayLogDateBetween(String userId,String projectId,String status,LocalDateTime start,LocalDateTime end);

    /**
     * 获取人员-项目-月度标准总工时
     * @param userId    用户ID
     * @return  汇总数据
     */
    @Query(value="SELECT SUM(chuanyun_self_work_hour.standard_work_hour) AS standard_work_hour," +
            "chuanyun_self_work_hour.day_log_date," +
            "chuanyun_self_work_hour.user_id," +
            "chuanyun_self_work_hour.project_id," +
            "chuanyun_self_work_hour.project_type," +
            "chuanyun_self_work_hour.status," +
            "chuanyun_self_work_hour.object_id " +
            "FROM chuanyun_self_work_hour " +
            "WHERE chuanyun_self_work_hour.user_id=? " +
            "GROUP BY chuanyun_self_work_hour.user_id," +
            "DATE_FORMAT(chuanyun_self_work_hour.day_log_date,'%Y-%m')," +
            "chuanyun_self_work_hour.project_id," +
            "chuanyun_self_work_hour.status," +
            "chuanyun_self_work_hour.project_type",
            nativeQuery = true)
    List<ChuanyunSelfWorkHourDO> getMonthProjectHour(String userId);

    /**
     * 获取人员月度标准工时汇总
     * @param userId    用户ID
     * @param dayLogDate    查询月份日期
     * @param status        工时状态
     * @return  汇总数据
     */
    @Query(value="SELECT SUM(chuanyun_self_work_hour.standard_work_hour) AS standard_work_hour," +
            "chuanyun_self_work_hour.day_log_date," +
            "chuanyun_self_work_hour.user_id," +
            "chuanyun_self_work_hour.status," +
            "chuanyun_self_work_hour.project_type," +
            "chuanyun_self_work_hour.project_id," +
            "chuanyun_self_work_hour.object_id "+
            "FROM chuanyun_self_work_hour " +
            "WHERE chuanyun_self_work_hour.user_id= ?1 " +
            "AND  chuanyun_self_work_hour.status= ?3 "+
            "AND DATE_FORMAT(chuanyun_self_work_hour.day_log_date,'%Y-%m')=DATE_FORMAT(?2,'%Y-%m') "+
            "GROUP BY chuanyun_self_work_hour.user_id," +
            "chuanyun_self_work_hour.status," +
            "DATE_FORMAT(chuanyun_self_work_hour.day_log_date,'%Y-%m')",
            nativeQuery = true)
    ChuanyunSelfWorkHourDO getMonthHour(@Param("userId") String userId,@Param("dayLogDate") String dayLogDate,@Param("status")String status);
}
