package com.galaxis.manatee.dao;


import com.galaxis.capsule.util.GalaxisRepository;
import com.galaxis.manatee.entity.chuanyun.data.object.ChuanyunWorkHourDO;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.time.LocalDateTime;
import java.util.List;

/**
 * @author kxuan
 */
@Repository
public interface ChuanyunWorkHourDao extends GalaxisRepository<ChuanyunWorkHourDO,String> {

    /**
     * 根据用户Id获取用户日志明细，并按日期拍
     * @param userId    用户Id
     * @return  日志数据
     */
    @Query(value="SELECT chuanyun_day_log.object_id," +
            "SUM(chuanyun_day_log.hours_worked) AS hours_worked," +
            "chuanyun_day_log.project_id," +
            "chuanyun_day_log.project_type," +
            "chuanyun_log.user_id," +
            "chuanyun_log.status," +
            "chuanyun_day_log.day_log_date " +
            "FROM chuanyun_day_log "+
            "LEFT JOIN chuanyun_log ON chuanyun_day_log.parent_object_id = chuanyun_log.object_id " +
            " WHERE chuanyun_log.user_id = ? " +
//            "AND chuanyun_log.log_date>='2020-08-01'" +
            " GROUP BY chuanyun_day_log.project_id," +
            "chuanyun_log.user_id," +
            "chuanyun_day_log.project_type," +
            "chuanyun_log.status," +
            "chuanyun_day_log.day_log_date",
            nativeQuery = true)
    List<ChuanyunWorkHourDO> getSelfWorkHour(String userId);

    /**
     * 根据用户ID和日期筛选工时数据
     * @param userId    用户Id
     * @param day   日期
     * @return  人员工时数据
     */
    @Query(value="SELECT chuanyun_day_log.object_id," +
            "SUM(chuanyun_day_log.hours_worked) AS hours_worked," +
            "chuanyun_day_log.project_id," +
            "chuanyun_day_log.project_type," +
            "chuanyun_log.user_id," +
            "chuanyun_log.status," +
            "chuanyun_day_log.day_log_date " +
            "FROM chuanyun_day_log "+
            "LEFT JOIN chuanyun_log ON chuanyun_day_log.parent_object_id = chuanyun_log.object_id " +
            "WHERE chuanyun_log.user_id = ? " +
            "AND chuanyun_day_log.day_log_date =? " +
            "GROUP BY chuanyun_log.user_id," +
            "chuanyun_day_log.day_log_date",
            nativeQuery = true)
    ChuanyunWorkHourDO getDayWorkHour(String userId,LocalDateTime day);
}
